@@ -34,18 +34,21 @@ BENCHMARK_PARAMS = pd.read_csv(S3_URL.format(
 PIPELINE_DIR = os.path.join(os.path.dirname(__file__), 'pipelines', 'verified')
 
 VERIFIED_PIPELINES = [
-    'arima', 'lstm_dynamic_threshold', 'azure'
+    'arima', 'lstm_dynamic_threshold', 'azure', 'tadgan'
 ]
 
 VERIFIED_PIPELINES_GPU = {
     'arima': 'arima',
     'lstm_dynamic_threshold': 'lstm_dynamic_threshold_gpu',
-    'azure': 'azure'
+    'azure': 'azure',
+    'tadgan': 'tadgan_gpu'
 }
 
 
-def _load_signal(signal, holdout):
-    if holdout:
+def _load_signal(signal, test_split):
+    if isinstance(test_split, float):
+        train, test = load_signal(signal, test_size=test_split)
+    elif test_split:
         train = load_signal(signal + '-train')
         test = load_signal(signal + '-test')
     else:
@@ -83,9 +86,9 @@ def _sort_leaderboard(df, rank, metrics):
 
 
 def _evaluate_signal(pipeline, name, dataset, signal, hyperparameter, metrics,
-                     holdout=True, detrend=False):
+                     test_split=False, detrend=False):
 
-    train, test = _load_signal(signal, holdout)
+    train, test = _load_signal(signal, test_split)
     truth = load_anomalies(signal)
 
     if detrend:
@@ -93,8 +96,8 @@ def _evaluate_signal(pipeline, name, dataset, signal, hyperparameter, metrics,
         test = _detrend_signal(test, 'value')
 
     try:
-        LOGGER.info("Scoring pipeline %s on signal %s (Holdout: %s)",
-                    name, signal, holdout)
+        LOGGER.info("Scoring pipeline %s on signal %s (test split: %s)",
+                    name, signal, test_split)
 
         start = datetime.utcnow()
         pipeline = _load_pipeline(pipeline, hyperparameter)
@@ -108,8 +111,8 @@ def _evaluate_signal(pipeline, name, dataset, signal, hyperparameter, metrics,
         scores['status'] = 'OK'
 
     except Exception as ex:
-        LOGGER.exception("Exception scoring pipeline %s on signal %s (Holdout: %s), error %s.",
-                         name, signal, holdout, ex)
+        LOGGER.exception("Exception scoring pipeline %s on signal %s (test split: %s), error %s.",
+                         name, signal, test_split, ex)
 
         elapsed = datetime.utcnow() - start
         scores = {
@@ -125,7 +128,7 @@ def _evaluate_signal(pipeline, name, dataset, signal, hyperparameter, metrics,
 
     scores['elapsed'] = elapsed.total_seconds()
     scores['pipeline'] = name
-    scores['holdout'] = holdout
+    scores['split'] = test_split
     scores['dataset'] = dataset
     scores['signal'] = signal
 
@@ -133,11 +136,11 @@ def _evaluate_signal(pipeline, name, dataset, signal, hyperparameter, metrics,
 
 
 def _evaluate_pipeline(pipeline, pipeline_name, dataset, signals, hyperparameter, metrics,
-                       distributed, holdout, detrend):
-    if holdout is None:
-        holdout = (True, False)
-    elif not isinstance(holdout, tuple):
-        holdout = (holdout, )
+                       distributed, test_split, detrend):
+    if test_split is None:
+        test_split = (True, False)
+    elif not isinstance(test_split, tuple):
+        test_split = (test_split, )
 
     # hyperparameter settings
     if hyperparameter is None:
@@ -159,9 +162,9 @@ def _evaluate_pipeline(pipeline, pipeline_name, dataset, signals, hyperparameter
     scores = list()
 
     for signal in signals:
-        for holdout_ in holdout:
+        for test_split_ in test_split:
             score = function(pipeline, pipeline_name, dataset, signal, hyperparameter,
-                             metrics, holdout_, detrend)
+                             metrics, test_split_, detrend)
 
             scores.append(score)
 
@@ -169,19 +172,19 @@ def _evaluate_pipeline(pipeline, pipeline_name, dataset, signals, hyperparameter
 
 
 def _evaluate_pipelines(pipelines, dataset, signals, hyperparameters, metrics, distributed,
-                        holdout, detrend):
+                        test_split, detrend):
 
     scores = list()
     for name, pipeline in pipelines.items():
         hyperparameter = _get_parameter(hyperparameters, name)
         score = _evaluate_pipeline(pipeline, name, dataset, signals, hyperparameter,
-                                   metrics, distributed, holdout, detrend)
+                                   metrics, distributed, test_split, detrend)
         scores.extend(score)
 
     return scores
 
 
-def _evaluate_datasets(pipelines, datasets, hyperparameters, metrics, distributed, holdout,
+def _evaluate_datasets(pipelines, datasets, hyperparameters, metrics, distributed, test_split,
                        detrend):
     delayed = []
     for dataset, signals in datasets.items():
@@ -192,10 +195,10 @@ def _evaluate_datasets(pipelines, datasets, hyperparameters, metrics, distribute
         hyperparameters_ = _get_parameter(hyperparameters, dataset)
         parameters = _get_parameter(BENCHMARK_PARAMS, dataset)
         if parameters is not None:
-            detrend, holdout = parameters.values()
+            detrend, test_split = parameters.values()
 
-        result = _evaluate_pipelines(
-            pipelines, dataset, signals, hyperparameters_, metrics, distributed, holdout, detrend)
+        result = _evaluate_pipelines(pipelines, dataset, signals, hyperparameters_,
+                                     metrics, distributed, test_split, detrend)
 
         delayed.extend(result)
 
@@ -210,7 +213,7 @@ def _evaluate_datasets(pipelines, datasets, hyperparameters, metrics, distribute
     return df
 
 
-def _summarize_results(df, metrics):
+def summarize_results(df, metrics):
     """ Summarize the result of benchmark.
 
     The table is summarized for according to the number of wins each pipeline
@@ -276,7 +279,7 @@ def _summarize_results(df, metrics):
 
 
 def benchmark(pipelines=None, datasets=None, hyperparameters=None, metrics=METRICS, rank='f1',
-              distributed=False, holdout=False, detrend=False, output_path=None):
+              distributed=False, test_split=False, detrend=False, output_path=None):
     """Evaluate pipelines on the given datasets and evaluate the performance.
 
     The pipelines are used to analyze the given signals and later on the
@@ -305,16 +308,16 @@ def benchmark(pipelines=None, datasets=None, hyperparameters=None, metrics=METRI
             If not given, rank using the first metric.
         distributed (bool): Whether to use dask for distributed computing. If not given,
             use ``False``.
-        holdout (bool): Whether to use the prespecified train-test split. If not given,
-            use ``False``.
+        test_split (bool or float): Whether to use the prespecified train-test split. If
+            float, then it should be between 0.0 and 1.0 and represent the proportion of
+            the signal to include in the test split. If not given, use ``False``.
         detrend (bool): Whether to use ``scipy.detrend``. If not given, use ``False``.
         output_path (str): Location to save the intermediatry results. If not given,
             intermediatry results will not be saved.
 
     Returns:
-        pandas.DataFrame: Table containing the average of the scores obtained with
-            each scoring function accross all the signals for each pipeline, ranked
-            by the indicated metric.
+        pandas.DataFrame: Table containing the scores obtained with
+            each scoring function accross all the signals for each pipeline.
     """
     pipelines = pipelines or VERIFIED_PIPELINES
     datasets = datasets or BENCHMARK_DATA
@@ -342,7 +345,7 @@ def benchmark(pipelines=None, datasets=None, hyperparameters=None, metrics=METRI
         metrics = metrics_
 
     results = _evaluate_datasets(
-        pipelines, datasets, hyperparameters, metrics, distributed, holdout, detrend)
+        pipelines, datasets, hyperparameters, metrics, distributed, test_split, detrend)
 
     if output_path:
         LOGGER.info('Saving benchmark report to %s', output_path)
@@ -369,7 +372,7 @@ def main(cuda=False, distributed=False):
     results = benchmark(
         pipelines=pipelines, metrics=metrics, output_path=output_path, distributed=distributed)
 
-    leaderboard = _summarize_results(results, metrics)
+    leaderboard = summarize_results(results, metrics)
     output_path = os.path.join(BENCHMARK_PATH, 'leaderboard.csv')
     leaderboard.to_csv(output_path)
 
